@@ -19,7 +19,6 @@
 # *
 # **************************************************************************
 
-__version__ = '0.0.9'
 __author__ = 'Jose Miguel de la Rosa Trevin, Grigory Sharov'
 
 
@@ -183,7 +182,6 @@ class _Reader(_ColumnsList):
                             values=values, guessType=guessType, types=types)
         self._types = [c.getType() for c in self.getColumns()]
 
-
         if self._singleRow:
             self._row = self.__rowFromValues(values)
         else:
@@ -206,6 +204,7 @@ class _Reader(_ColumnsList):
             self._row = None
         elif result is not None:
             line = self._file.readline().strip()
+            line = None if line.startswith("data_") else line
             self._row = self.__rowFromValues(line.split()) if line else None
 
         return result
@@ -228,14 +227,14 @@ class _Reader(_ColumnsList):
 
         rawLine = inputFile.readline()
         while rawLine:
-            if rawLine.startswith('_'):
-                line = rawLine
+            line = rawLine.strip()
+            if line.startswith('_'):
                 break
-            elif rawLine.startswith('loop_'):
+            elif line.startswith('loop_'):
                 foundLoop = True
             rawLine = inputFile.readline()
 
-        return line.strip(), foundLoop
+        return line, foundLoop
 
     def readAll(self):
         """ Read all rows and return as a list. """
